summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJosh Stone <jistone@redhat.com>2011-01-11 19:16:58 -0800
committerRoland McGrath <roland@redhat.com>2011-01-12 10:27:43 -0800
commitcf51471777953c1c6cfcbe7ad5df09c23c1964be (patch)
tree8dcba98ecb331bd9ccc955680c08ec41ee99d941
parentd41d9a6917721152ad2a9963cf8f487787041e9e (diff)
downloadelfutils-cf51471777953c1c6cfcbe7ad5df09c23c1964be.tar.gz
Expand testfile53 for 32/64-bit
-rw-r--r--tests/ChangeLog9
-rw-r--r--tests/Makefile.am4
-rwxr-xr-xtests/run-prelink-addr-test.sh42
-rwxr-xr-xtests/testfile53-32.bz2bin0 -> 1628 bytes
-rwxr-xr-xtests/testfile53-32.debug.bz2bin0 -> 1959 bytes
-rwxr-xr-xtests/testfile53-32.prelink.bz2bin0 -> 2192 bytes
-rwxr-xr-xtests/testfile53-64.bz2bin0 -> 1683 bytes
-rwxr-xr-xtests/testfile53-64.debug.bz2bin0 -> 1927 bytes
-rwxr-xr-xtests/testfile53-64.prelink.bz2bin0 -> 2180 bytes
-rwxr-xr-xtests/testfile53.bz2bin1687 -> 0 bytes
-rwxr-xr-xtests/testfile53.debug.bz2bin1897 -> 0 bytes
-rwxr-xr-xtests/testfile53.prelink.bz2bin2192 -> 0 bytes
12 files changed, 42 insertions, 13 deletions
diff --git a/tests/ChangeLog b/tests/ChangeLog
index df97240a..bb5634da 100644
--- a/tests/ChangeLog
+++ b/tests/ChangeLog
@@ -1,5 +1,14 @@
2011-01-11 Josh Stone <jistone@redhat.com>
+ * run-prelink-addr-test.sh: Run 32 and 64-bit testfile53 tests.
+ * testfile53.bz2, testfile53.debug.bz2,
+ testfile53.prelink.bz2: Deleted, so...
+ * testfile53-64.bz2, testfile53-64.debug.bz2,
+ testfile53-64.prelink.bz2: Recreated with 64-bit names.
+ * testfile53-32.bz2, testfile53-32.debug.bz2,
+ testfile53-32.prelink.bz2: New in 32-bit.
+ * Makefile.am (EXTRA_DIST): Add and update all.
+
* run-prelink-addr-test.sh: Run 32 and 64-bit testfile52 tests.
* testfile52.so.bz2, testfile52.so.debug.bz2,
testfile52.prelink.so.bz2: Deleted, so...
diff --git a/tests/Makefile.am b/tests/Makefile.am
index 2ab961c3..9f191ce2 100644
--- a/tests/Makefile.am
+++ b/tests/Makefile.am
@@ -145,7 +145,9 @@ EXTRA_DIST = run-arextract.sh run-arsymtest.sh \
testfile52-32.prelink.so.bz2 testfile52-32.noshdrs.so.bz2 \
testfile52-64.so.bz2 testfile52-64.so.debug.bz2 \
testfile52-64.prelink.so.bz2 testfile52-64.noshdrs.so.bz2 \
- testfile53.bz2 testfile53.debug.bz2 testfile53.prelink.bz2
+ testfile53-32.bz2 testfile53-32.debug.bz2 \
+ testfile53-32.prelink.bz2 testfile53-64.bz2 \
+ testfile53-64.debug.bz2 testfile53-64.prelink.bz2
installed_TESTS_ENVIRONMENT = libdir=$(DESTDIR)$(libdir) \
bindir=$(DESTDIR)$(bindir) \
diff --git a/tests/testfile53-32.bz2 b/tests/testfile53-32.bz2
new file mode 100755
index 00000000..7bf48d9f
--- /dev/null
+++ b/tests/testfile53-32.bz2
Binary files differ
diff --git a/tests/testfile53-32.debug.bz2 b/tests/testfile53-32.debug.bz2
new file mode 100755
index 00000000..79ea566d
--- /dev/null
+++ b/tests/testfile53-32.debug.bz2
Binary files differ
diff --git a/tests/testfile53-32.prelink.bz2 b/tests/testfile53-32.prelink.bz2
new file mode 100755
index 00000000..8e05abf0
--- /dev/null
+++ b/tests/testfile53-32.prelink.bz2
Binary files differ
diff --git a/tests/testfile53-64.bz2 b/tests/testfile53-64.bz2
new file mode 100755
index 00000000..235a7631
--- /dev/null
+++ b/tests/testfile53-64.bz2
Binary files differ
diff --git a/tests/testfile53-64.debug.bz2 b/tests/testfile53-64.debug.bz2
new file mode 100755
index 00000000..675c6eaf
--- /dev/null
+++ b/tests/testfile53-64.debug.bz2
Binary files differ
diff --git a/tests/testfile53-64.prelink.bz2 b/tests/testfile53-64.prelink.bz2
new file mode 100755
index 00000000..853aba78
--- /dev/null
+++ b/tests/testfile53-64.prelink.bz2
Binary files differ
diff --git a/tests/testfile53.bz2 b/tests/testfile53.bz2
deleted file mode 100755
index 2e0e74c8..00000000
--- a/tests/testfile53.bz2
+++ /dev/null
Binary files differ
diff --git a/tests/testfile53.debug.bz2 b/tests/testfile53.debug.bz2
deleted file mode 100755
index ec36e982..00000000
--- a/tests/testfile53.debug.bz2
+++ /dev/null
Binary files differ
diff --git a/tests/testfile53.prelink.bz2 b/tests/testfile53.prelink.bz2
deleted file mode 100755
index b2f4dea9..00000000
--- a/tests/testfile53.prelink.bz2
+++ /dev/null
Binary files differ
diff --git a/tests/run-prelink-addr-test.sh b/tests/run-prelink-addr-test.sh
index 6938ec15..e554d4b0 100755
--- a/tests/run-prelink-addr-test.sh
+++ b/tests/run-prelink-addr-test.sh
@@ -94,26 +94,44 @@ EOF
# testfile53.c:
-# char foo[2000];
+# char foo[0x1000];
# int main() { return 0; }
#
-# gcc -g testfile53.c -o testfile53
-# eu-strip -f testfile53.debug testfile53
-# cp testfile53 testfile53.prelinked
-# prelink -N testfile53.prelinked
-testfiles testfile53 testfile53.prelink testfile53.debug
+# gcc -m32 -g testfile53-32.c -o testfile53-32
+# eu-strip -f testfile53-32.debug testfile53-32
+# cp testfile53-32 testfile53-32.prelink
+# prelink -N testfile53-32.prelink
+testfiles testfile53-32 testfile53-32.debug testfile53-32.prelink
-testrun_compare ../src/addr2line -S -e testfile53 0x400474 0x400475 <<\EOF
+testrun_compare ../src/addr2line -S -e testfile53-32 0x8048394 0x8048395 <<\EOF
main
-/home/jistone/src/elfutils/tests/testfile53.c:2
+/home/jistone/src/elfutils/tests/testfile53-32.c:2
main+0x1
-/home/jistone/src/elfutils/tests/testfile53.c:2
+/home/jistone/src/elfutils/tests/testfile53-32.c:2
EOF
# prelink shuffled some of the sections, but .text is in the same place.
-testrun_compare ../src/addr2line -S -e testfile53.prelink 0x400476 0x400477 <<\EOF
+testrun_compare ../src/addr2line -S -e testfile53-32.prelink 0x8048396 0x8048397 <<\EOF
main+0x2
-/home/jistone/src/elfutils/tests/testfile53.c:2
+/home/jistone/src/elfutils/tests/testfile53-32.c:2
main+0x3
-/home/jistone/src/elfutils/tests/testfile53.c:2
+/home/jistone/src/elfutils/tests/testfile53-32.c:2
+EOF
+
+# Repeat testfile53 in 64-bit, except use foo[0x800] to achieve the same
+# prelink section shuffling.
+testfiles testfile53-64 testfile53-64.debug testfile53-64.prelink
+
+testrun_compare ../src/addr2line -S -e testfile53-64 0x400474 0x400475 <<\EOF
+main
+/home/jistone/src/elfutils/tests/testfile53-64.c:2
+main+0x1
+/home/jistone/src/elfutils/tests/testfile53-64.c:2
+EOF
+
+testrun_compare ../src/addr2line -S -e testfile53-64.prelink 0x400476 0x400477 <<\EOF
+main+0x2
+/home/jistone/src/elfutils/tests/testfile53-64.c:2
+main+0x3
+/home/jistone/src/elfutils/tests/testfile53-64.c:2
EOF